@@ -27,6 +27,7 @@ class Objects(ApiManager):
             extract_severity (boolean optional): Se True nella risposta e' anche presente la severita, Default to False. - parameter
             count_children (boolean optional): additional filter - parameter
             severity (string optional): additional filter - parameter
+            ip_cidr (string optional): additional filter - parameter
             skip (integer optional): numero di oggetti che si vogliono saltare nella risposta. Default to 0. - parameter
             limit (integer optional): numero di oggetti massimi che si vogliono ottenere. Default to 1_000_000. - parameter
             like (boolean optional): Se True, eventuali filtri richiesti dalla API vengono presi come porzioni di testo, se False il matching sul campo dei filtri deve essere esatto. Default to True. - parameter
@@ -39,14 +40,14 @@ class Objects(ApiManager):
         official_params_list = ['sort_by', 'null_fields', 'not_fields',
             'name', 'description', 'feedback_for_operator', 'profile',
             'status', 'extract_severity', 'count_children', 'severity',
-            'skip', 'limit', 'like', 'join', 'count']
+            'ip_cidr', 'skip', 'limit', 'like', 'join', 'count']
         params.get('sort_by'), params.get('null_fields'), params.get(
             'not_fields'), params.get('name'), params.get('description'
             ), params.get('feedback_for_operator'), params.get('profile'
             ), params.get('status'), params.get('extract_severity'
             ), params.get('count_children'), params.get('severity'
-            ), params.get('skip'), params.get('limit'), params.get('like'
-            ), params.get('join'), params.get('count')
+            ), params.get('ip_cidr'), params.get('skip'), params.get('limit'
+            ), params.get('like'), params.get('join'), params.get('count')
         if not self._silence_warning:
             warning_wrong_parameters(self.objects.__name__, params,
                 official_params_list)
