@@ -768,6 +768,221 @@ class Services(ApiManager):
             warm_start, params=params, payload=payload, **kwargs)
         return response
 
+    def services_last_status_query_v2(self, warm_start: bool = False,
+        single_page: bool = False, page_size: int = 5000,
+        kwargs: dict = None, **params) -> list:
+        """Service Query Last Status V2
+
+        Args:
+            warm_start (bool, optional): salva la risposta in un file e se viene richiamata la stessa funzione con gli stessi argomenti restituisce il contenuto del file. Default to False.
+            single_page (bool, optional): se False la risposta viene ottenuta a step per non appesantire le API. Default to False.
+            page_size (int, optional): Numero di oggetti per pagina se single_page == False. Default to 5000.
+            kwargs (dict, optional): additional parameters for execute. Default to None.
+            **params: additional parameters for the API.
+
+        Keyword Args:
+            sort_by (string optional): Stringa separata da virgole di campi su cui ordinare. Si indica uno o piu campi della risposta e si puo chiedere di ottenere i valori di quei campi in ordine ascendente o discendente. Esempio "Customer:Desc". Default to "". - parameter
+            null_fields (string optional): additional filter - parameter
+            uuid_customer (string optional): additional filter - parameter
+            customer_code (string optional): additional filter - parameter
+            customer_status (string optional): additional filter - parameter
+            uuid_site (string optional): additional filter - parameter
+            site_code (string optional): additional filter - parameter
+            site_description (string optional): additional filter - parameter
+            site_address (string optional): additional filter - parameter
+            site_zip_code (string optional): additional filter - parameter
+            site_city (string optional): additional filter - parameter
+            site_country (string optional): additional filter - parameter
+            site_state_province (string optional): additional filter - parameter
+            site_status (string optional): additional filter - parameter
+            uuid_group (string optional): additional filter - parameter
+            group_name (string optional): additional filter - parameter
+            group_status (string optional): additional filter - parameter
+            group_type (string optional): additional filter - parameter
+            group_uuid_virtual_domain (string optional): additional filter - parameter
+            uuid_object (string optional): additional filter - parameter
+            object_name (string optional): additional filter - parameter
+            object_status (string optional): additional filter - parameter
+            object_profile (string optional): additional filter - parameter
+            uuid_metric_type (string optional): additional filter - parameter
+            metric_type_name (string optional): additional filter - parameter
+            metric_type_status (string optional): additional filter - parameter
+            uuid_metric (string optional): additional filter - parameter
+            metric_name (string optional): additional filter - parameter
+            metric_status (string optional): additional filter - parameter
+            metric_profile (string optional): additional filter - parameter
+            service_uuid_parent (string optional): additional filter - parameter
+            uuid_service (string optional): additional filter - parameter
+            service_profile (string optional): additional filter - parameter
+            service_name (string optional): additional filter - parameter
+            service_description (string optional): additional filter - parameter
+            service_status (string optional): additional filter - parameter
+            service_automata_domain (string optional): additional filter - parameter
+            service_uuid_customer (string optional): additional filter - parameter
+            timestamp_start (string optional): additional filter - parameter
+            timestamp_end (string optional): additional filter - parameter
+            database_timestamp_start (string optional): additional filter - parameter
+            database_timestamp_end (string optional): additional filter - parameter
+            status (string optional): additional filter - parameter
+            ranking (integer optional): additional filter - parameter
+            description (string optional): additional filter - parameter
+            unit (string optional): additional filter - parameter
+            value (number optional): additional filter - parameter
+            fields_to_select (array optional): additional filter - parameter
+            skip (integer optional): numero di oggetti che si vogliono saltare nella risposta. Default to 0. - parameter
+            limit (integer optional): numero di oggetti massimi che si vogliono ottenere. Default to 1_000_000. - parameter
+            like (boolean optional): Se True, eventuali filtri richiesti dalla API vengono presi come porzioni di testo, se False il matching sul campo dei filtri deve essere esatto. Default to True. - parameter
+            join (boolean optional): Se join = true, ogni riga restituita conterra' chiavi aggiuntive che fanno riferimento ad altre entita', con cui la riga ha relazioni 1:1. Default to False - parameter
+            count (boolean optional): Se True nel header della risposta e' presente la dimensione massima a db della chiamata fatta, sconsigliabile perche raddoppia il tempo per chiamata. Default to False. - parameter
+
+        Returns: list"""
+        if kwargs is None:
+            kwargs = dict()
+        official_params_list = ['sort_by', 'null_fields', 'uuid_customer',
+            'customer_code', 'customer_status', 'uuid_site', 'site_code',
+            'site_description', 'site_address', 'site_zip_code',
+            'site_city', 'site_country', 'site_state_province',
+            'site_status', 'uuid_group', 'group_name', 'group_status',
+            'group_type', 'group_uuid_virtual_domain', 'uuid_object',
+            'object_name', 'object_status', 'object_profile',
+            'uuid_metric_type', 'metric_type_name', 'metric_type_status',
+            'uuid_metric', 'metric_name', 'metric_status', 'metric_profile',
+            'service_uuid_parent', 'uuid_service', 'service_profile',
+            'service_name', 'service_description', 'service_status',
+            'service_automata_domain', 'service_uuid_customer',
+            'timestamp_start', 'timestamp_end', 'database_timestamp_start',
+            'database_timestamp_end', 'status', 'ranking', 'description',
+            'unit', 'value', 'fields_to_select', 'skip', 'limit', 'like',
+            'join', 'count']
+        params.get('sort_by'), params.get('null_fields'), params.get(
+            'uuid_customer'), params.get('customer_code'), params.get(
+            'customer_status'), params.get('uuid_site'), params.get('site_code'
+            ), params.get('site_description'), params.get('site_address'
+            ), params.get('site_zip_code'), params.get('site_city'
+            ), params.get('site_country'), params.get('site_state_province'
+            ), params.get('site_status'), params.get('uuid_group'), params.get(
+            'group_name'), params.get('group_status'), params.get('group_type'
+            ), params.get('group_uuid_virtual_domain'), params.get(
+            'uuid_object'), params.get('object_name'), params.get(
+            'object_status'), params.get('object_profile'), params.get(
+            'uuid_metric_type'), params.get('metric_type_name'), params.get(
+            'metric_type_status'), params.get('uuid_metric'), params.get(
+            'metric_name'), params.get('metric_status'), params.get(
+            'metric_profile'), params.get('service_uuid_parent'), params.get(
+            'uuid_service'), params.get('service_profile'), params.get(
+            'service_name'), params.get('service_description'), params.get(
+            'service_status'), params.get('service_automata_domain'
+            ), params.get('service_uuid_customer'), params.get(
+            'timestamp_start'), params.get('timestamp_end'), params.get(
+            'database_timestamp_start'), params.get('database_timestamp_end'
+            ), params.get('status'), params.get('ranking'), params.get(
+            'description'), params.get('unit'), params.get('value'
+            ), params.get('fields_to_select'), params.get('skip'), params.get(
+            'limit'), params.get('like'), params.get('join'), params.get(
+            'count')
+        if not self._silence_warning:
+            warning_wrong_parameters(self.services_last_status_query_v2.
+                __name__, params, official_params_list)
+        response = self.execute('GET', path=
+            f'/services/query/last_status_v2', single_page=single_page,
+            page_size=page_size, warm_start=warm_start, params=params, **kwargs
+            )
+        return response
+
+    def services_last_status_query_bulk_v2(self, payload: dict = False,
+        warm_start: bool = False, single_page: bool = False,
+        page_size: int = 5000, kwargs: dict = None, **params) -> list:
+        """Service Query Last Status List V2
+
+        Args:
+            payload (dict, optional): additional parameters for the API.
+            warm_start (bool, optional): salva la risposta in un file e se viene richiamata la stessa funzione con gli stessi argomenti restituisce il contenuto del file. Default to False.
+            single_page (bool, optional): se False la risposta viene ottenuta a step per non appesantire le API. Default to False.
+            page_size (int, optional): Numero di oggetti per pagina se single_page == False. Default to 5000.
+            kwargs (dict, optional): additional parameters for execute. Default to None.
+            **params: additional parameters for the API.
+
+        Keyword Args:
+            sort_by (string optional): Stringa separata da virgole di campi su cui ordinare. Si indica uno o piu campi della risposta e si puo chiedere di ottenere i valori di quei campi in ordine ascendente o discendente. Esempio "Customer:Desc". Default to "". - parameter
+            null_fields (string optional): additional filter - parameter
+            timestamp_start (string optional): additional filter - parameter
+            timestamp_end (string optional): additional filter - parameter
+            database_timestamp_start (string optional): additional filter - parameter
+            database_timestamp_end (string optional): additional filter - parameter
+            skip (integer optional): numero di oggetti che si vogliono saltare nella risposta. Default to 0. - parameter
+            limit (integer optional): numero di oggetti massimi che si vogliono ottenere. Default to 1_000_000. - parameter
+            like (boolean optional): Se True, eventuali filtri richiesti dalla API vengono presi come porzioni di testo, se False il matching sul campo dei filtri deve essere esatto. Default to True. - parameter
+            join (boolean optional): Se join = true, ogni riga restituita conterra' chiavi aggiuntive che fanno riferimento ad altre entita', con cui la riga ha relazioni 1:1. Default to False - parameter
+            count (boolean optional): Se True nel header della risposta e' presente la dimensione massima a db della chiamata fatta, sconsigliabile perche raddoppia il tempo per chiamata. Default to False. - parameter
+
+        Examples:
+            payload = 
+           {
+            "uuid_customer": "array", optional
+            "customer_code": "array", optional
+            "customer_status": "array", optional
+            "uuid_site": "array", optional
+            "site_code": "array", optional
+            "site_description": "array", optional
+            "site_address": "array", optional
+            "site_zip_code": "array", optional
+            "site_city": "array", optional
+            "site_country": "array", optional
+            "site_state_province": "array", optional
+            "site_status": "array", optional
+            "uuid_group": "array", optional
+            "group_name": "array", optional
+            "group_status": "array", optional
+            "group_type": "array", optional
+            "group_uuid_virtual_domain": "array", optional
+            "uuid_object": "array", optional
+            "object_name": "array", optional
+            "object_status": "array", optional
+            "object_profile": "array", optional
+            "uuid_metric_type": "array", optional
+            "metric_type_name": "array", optional
+            "metric_type_status": "array", optional
+            "uuid_metric": "array", optional
+            "metric_name": "array", optional
+            "metric_status": "array", optional
+            "metric_profile": "array", optional
+            "service_uuid_parent": "array", optional
+            "uuid_service": "array", optional
+            "service_profile": "array", optional
+            "service_name": "array", optional
+            "service_description": "array", optional
+            "service_status": "array", optional
+            "service_automata_domain": "array", optional
+            "service_uuid_customer": "array", optional
+            "status": "array", optional
+            "ranking": "array", optional
+            "description": "array", optional
+            "unit": "array", optional
+            "value": "array", optional
+            "fields_to_select": "array", optional
+           }
+
+        Returns: list"""
+        if kwargs is None:
+            kwargs = dict()
+        official_params_list = ['sort_by', 'null_fields', 'timestamp_start',
+            'timestamp_end', 'database_timestamp_start',
+            'database_timestamp_end', 'skip', 'limit', 'like', 'join', 'count']
+        params.get('sort_by'), params.get('null_fields'), params.get(
+            'timestamp_start'), params.get('timestamp_end'), params.get(
+            'database_timestamp_start'), params.get('database_timestamp_end'
+            ), params.get('skip'), params.get('limit'), params.get('like'
+            ), params.get('join'), params.get('count')
+        if not self._silence_warning:
+            warning_wrong_parameters(self.
+                services_last_status_query_bulk_v2.__name__, params,
+                official_params_list)
+        response = self.execute('POST', path=
+            f'/services/query/last_status_v2', single_page=single_page,
+            page_size=page_size, warm_start=warm_start, params=params,
+            payload=payload, **kwargs)
+        return response
+
     def services_check_rules_create(self, params: dict = False,
         kwargs: dict = None, **payload) -> list:
         """Check Service Rules
@@ -780,6 +995,7 @@ class Services(ApiManager):
         Keyword Args:
             uuid_group (string optional): additional filter - parameter
             uuid_object (string optional): additional filter - parameter
+            uuid_metric_type (string optional): additional filter - parameter
             uuid_metric (string optional): additional filter - parameter
             services_rules (array required): additional filter - payload
             default_service (None required): additional filter - payload
